@@ -43,10 +43,6 @@
 		#include <mach/mach_time.h>
 	#endif
 
-	#if defined(__ANDROID__)
-		#include <android/log.h>
-	#endif
-
 #elif defined(CONF_FAMILY_WINDOWS)
 	#define WIN32_LEAN_AND_MEAN
 	#undef _WIN32_WINNT
@@ -125,7 +121,6 @@ void dbg_msg(const char *sys, const char *fmt, ...)
 	char str[1024*4];
 	int i;
 
-	//str_format(str, sizeof(str), "[%08x][%s]: ", (int)time(0), sys);
 	char timestr[80];
 	str_timestamp_format(timestr, sizeof(timestr), FORMAT_SPACE);
 
@@ -146,16 +141,12 @@ void dbg_msg(const char *sys, const char *fmt, ...)
 		loggers[i].logger(str, loggers[i].user);
 }
 
-#if defined(CONF_FAMILY_WINDOWS) || defined(__ANDROID__)
+#if defined(CONF_FAMILY_WINDOWS)
 static void logger_debugger(const char *line, void *user)
 {
 	(void)user;
-#if defined(CONF_FAMILY_WINDOWS)
 	OutputDebugString(line);
 	OutputDebugString("\n");
-#elif defined(__ANDROID__)
-	__android_log_print(ANDROID_LOG_INFO, "DDNet", "%s", line);
-#endif
 }
 #endif
 
@@ -172,27 +163,29 @@ static void logger_file(const char *line, void *user)
 #if defined(CONF_FAMILY_WINDOWS)
 static void logger_stdout_sync(const char *line, void *user)
 {
-	(void)user;
-
 	size_t length = strlen(line);
 	wchar_t *wide = malloc(length * sizeof (*wide));
-	mem_zero(wide, length * sizeof *wide);
-
 	const char *p = line;
 	int wlen = 0;
+	HANDLE console;
+
+	(void)user;
+	mem_zero(wide, length * sizeof *wide);
+
 	for(int codepoint = 0; (codepoint = str_utf8_decode(&p)); wlen++)
 	{
+		char u16[4] = {0};
+
 		if(codepoint < 0)
 			return;
 
-		char u16[4] = {0};
 		if(str_utf16le_encode(u16, codepoint) != 2)
 			return;
 
 		mem_copy(&wide[wlen], u16, 2);
 	}
 
-	HANDLE console = GetStdHandle(STD_OUTPUT_HANDLE);
+	console = GetStdHandle(STD_OUTPUT_HANDLE);
 	WriteConsoleW(console, wide, wlen, NULL, NULL);
 	WriteConsoleA(console, "\n", 1, NULL, NULL);
 }
@@ -249,7 +242,7 @@ void dbg_logger_stdout()
 
 void dbg_logger_debugger()
 {
-#if defined(CONF_FAMILY_WINDOWS) || defined(__ANDROID__)
+#if defined(CONF_FAMILY_WINDOWS)
 	dbg_logger(logger_debugger, 0, 0);
 #endif
 }
@@ -364,8 +357,7 @@ int io_close(IOHANDLE io)
 
 int io_flush(IOHANDLE io)
 {
-	fflush((FILE*)io);
-	return 0;
+	return fflush((FILE*)io);
 }
 
 
@@ -524,7 +516,7 @@ ASYNCIO *aio_new(IOHANDLE io)
 	aio->finish = ASYNCIO_RUNNING;
 	aio->refcount = 2;
 
-	aio->thread = thread_init(aio_thread, aio);
+	aio->thread = thread_init(aio_thread, aio, "aio");
 	if(!aio->thread)
 	{
 		free(aio->buffer);
@@ -706,7 +698,7 @@ static unsigned long __stdcall thread_run(void *user)
 	return 0;
 }
 
-void *thread_init(void (*threadfunc)(void *), void *u)
+void *thread_init(void (*threadfunc)(void *), void *u, const char *name)
 {
 	struct THREAD_RUN *data = malloc(sizeof(*data));
 	data->threadfunc = threadfunc;
@@ -714,8 +706,10 @@ void *thread_init(void (*threadfunc)(void *), void *u)
 #if defined(CONF_FAMILY_UNIX)
 	{
 		pthread_t id;
-		if(pthread_create(&id, NULL, thread_run, data) != 0)
+		int result = pthread_create(&id, NULL, thread_run, data);
+		if(result != 0)
 		{
+			dbg_msg("thread", "creating %s thread failed: %d", name, result);
 			return 0;
 		}
 		return (void*)id;
@@ -744,7 +738,9 @@ void thread_wait(void *thread)
 void thread_yield()
 {
 #if defined(CONF_FAMILY_UNIX)
-	sched_yield();
+	int result = sched_yield();
+	if(result != 0)
+		dbg_msg("thread", "yield failed: %d", errno);
 #elif defined(CONF_FAMILY_WINDOWS)
 	Sleep(0);
 #else
@@ -755,7 +751,10 @@ void thread_yield()
 void thread_sleep(int microseconds)
 {
 #if defined(CONF_FAMILY_UNIX)
-	usleep(microseconds);
+	int result = usleep(microseconds);
+	/* ignore signal interruption */
+	if(result == -1 && errno != EINTR)
+		dbg_msg("thread", "sleep failed: %d", errno);
 #elif defined(CONF_FAMILY_WINDOWS)
 	Sleep(microseconds/1000);
 #else
@@ -766,7 +765,9 @@ void thread_sleep(int microseconds)
 void thread_detach(void *thread)
 {
 #if defined(CONF_FAMILY_UNIX)
-	pthread_detach((pthread_t)(thread));
+	int result = pthread_detach((pthread_t)(thread));
+	if(result != 0)
+		dbg_msg("thread", "detach failed: %d", result);
 #elif defined(CONF_FAMILY_WINDOWS)
 	CloseHandle(thread);
 #else
@@ -774,6 +775,13 @@ void thread_detach(void *thread)
 #endif
 }
 
+void *thread_init_and_detach(void (*threadfunc)(void *), void *u, const char *name)
+{
+	void *thread = thread_init(threadfunc, u, name);
+	if(thread)
+		thread_detach(thread);
+	return thread;
+}
 
 
 
@@ -788,9 +796,20 @@ typedef CRITICAL_SECTION LOCKINTERNAL;
 LOCK lock_create()
 {
 	LOCKINTERNAL *lock = (LOCKINTERNAL *)malloc(sizeof(*lock));
+#if defined(CONF_FAMILY_UNIX)
+	int result;
+#endif
+
+	if(!lock)
+		return 0;
 
 #if defined(CONF_FAMILY_UNIX)
-	pthread_mutex_init(lock, 0x0);
+	result = pthread_mutex_init(lock, 0x0);
+	if(result != 0)
+	{
+		dbg_msg("lock", "init failed: %d", result);
+		return 0;
+	}
 #elif defined(CONF_FAMILY_WINDOWS)
 	InitializeCriticalSection((LPCRITICAL_SECTION)lock);
 #else
@@ -802,7 +821,9 @@ LOCK lock_create()
 void lock_destroy(LOCK lock)
 {
 #if defined(CONF_FAMILY_UNIX)
-	pthread_mutex_destroy((LOCKINTERNAL *)lock);
+	int result = pthread_mutex_destroy((LOCKINTERNAL *)lock);
+	if(result != 0)
+		dbg_msg("lock", "destroy failed: %d", result);
 #elif defined(CONF_FAMILY_WINDOWS)
 	DeleteCriticalSection((LPCRITICAL_SECTION)lock);
 #else
@@ -825,7 +846,9 @@ int lock_trylock(LOCK lock)
 void lock_wait(LOCK lock)
 {
 #if defined(CONF_FAMILY_UNIX)
-	pthread_mutex_lock((LOCKINTERNAL *)lock);
+	int result = pthread_mutex_lock((LOCKINTERNAL *)lock);
+	if(result != 0)
+		dbg_msg("lock", "lock failed: %d", result);
 #elif defined(CONF_FAMILY_WINDOWS)
 	EnterCriticalSection((LPCRITICAL_SECTION)lock);
 #else
@@ -836,7 +859,9 @@ void lock_wait(LOCK lock)
 void lock_unlock(LOCK lock)
 {
 #if defined(CONF_FAMILY_UNIX)
-	pthread_mutex_unlock((LOCKINTERNAL *)lock);
+	int result = pthread_mutex_unlock((LOCKINTERNAL *)lock);
+	if(result != 0)
+		dbg_msg("lock", "unlock failed: %d", result);
 #elif defined(CONF_FAMILY_WINDOWS)
 	LeaveCriticalSection((LPCRITICAL_SECTION)lock);
 #else
@@ -866,10 +891,28 @@ void sphore_destroy(SEMAPHORE *sem)
 	sem_unlink(aBuf);
 }
 #elif defined(CONF_FAMILY_UNIX)
-void sphore_init(SEMAPHORE *sem) { sem_init(sem, 0, 0); }
-void sphore_wait(SEMAPHORE *sem) { sem_wait(sem); }
-void sphore_signal(SEMAPHORE *sem) { sem_post(sem); }
-void sphore_destroy(SEMAPHORE *sem) { sem_destroy(sem); }
+void sphore_init(SEMAPHORE *sem)
+{
+	if(sem_init(sem, 0, 0) != 0)
+		dbg_msg("sphore", "init failed: %d", errno);
+}
+
+void sphore_wait(SEMAPHORE *sem)
+{
+	if(sem_wait(sem) != 0)
+		dbg_msg("sphore", "wait failed: %d", errno);
+}
+
+void sphore_signal(SEMAPHORE *sem)
+{
+	if(sem_post(sem) != 0)
+		dbg_msg("sphore", "post failed: %d", errno);
+}
+void sphore_destroy(SEMAPHORE *sem)
+{
+	if(sem_destroy(sem) != 0)
+		dbg_msg("sphore", "destroy failed: %d", errno);
+}
 #endif
 
 static int new_tick = -1;
@@ -901,7 +944,11 @@ int64 time_get_impl()
 		return last;
 #elif defined(CONF_FAMILY_UNIX)
 		struct timespec spec;
-		clock_gettime(CLOCK_MONOTONIC, &spec);
+		if(clock_gettime(CLOCK_MONOTONIC, &spec) != 0)
+		{
+			dbg_msg("clock", "gettime failed: %d", errno);
+			return 0;
+		}
 		last = (int64)spec.tv_sec*(int64)1000000 + (int64)spec.tv_nsec / 1000;
 		return last;
 #elif defined(CONF_FAMILY_WINDOWS)
@@ -1247,7 +1294,8 @@ static void priv_net_close_socket(int sock)
 #if defined(CONF_FAMILY_WINDOWS)
 	closesocket(sock);
 #else
-	close(sock);
+	if(close(sock) != 0)
+		dbg_msg("socket", "close failed: %d", errno);
 #endif
 }
 
@@ -1307,7 +1355,8 @@ static int priv_net_create_socket(int domain, int type, struct sockaddr *addr, i
 	if (domain == AF_INET && type == SOCK_STREAM)
 	{
 		int option = 1;
-		setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, &option, sizeof(option));
+		if(setsockopt(sock, SOL_SOCKET, SO_REUSEADDR, &option, sizeof(option)) != 0)
+			dbg_msg("socket", "Setting SO_REUSEADDR failed: %d", errno);
 	}
 #endif
 
@@ -1316,7 +1365,8 @@ static int priv_net_create_socket(int domain, int type, struct sockaddr *addr, i
 	if(domain == AF_INET6)
 	{
 		int ipv6only = 1;
-		setsockopt(sock, IPPROTO_IPV6, IPV6_V6ONLY, (const char*)&ipv6only, sizeof(ipv6only));
+		if(setsockopt(sock, IPPROTO_IPV6, IPV6_V6ONLY, (const char*)&ipv6only, sizeof(ipv6only)) != 0)
+			dbg_msg("socket", "Setting V6ONLY failed: %d", errno);
 	}
 #endif
 
@@ -1362,13 +1412,15 @@ NETSOCKET net_udp_create(NETADDR bindaddr)
 			sock.ipv4sock = socket;
 
 			/* set broadcast */
-			setsockopt(socket, SOL_SOCKET, SO_BROADCAST, (const char*)&broadcast, sizeof(broadcast));
+			if(setsockopt(socket, SOL_SOCKET, SO_BROADCAST, (const char*)&broadcast, sizeof(broadcast)) != 0)
+				dbg_msg("socket", "Setting BROADCAST on ipv4 failed: %d", errno);
 
 			{
 				/* set DSCP/TOS */
 				int iptos = 0x10 /* IPTOS_LOWDELAY */;
 				//int iptos = 46; /* High Priority */
-				setsockopt(socket, IPPROTO_IP, IP_TOS, (char*)&iptos, sizeof(iptos));
+				if(setsockopt(socket, IPPROTO_IP, IP_TOS, (char*)&iptos, sizeof(iptos)) != 0)
+					dbg_msg("socket", "Setting TOS on ipv4 failed: %d", errno);
 			}
 		}
 	}
@@ -1407,13 +1459,15 @@ NETSOCKET net_udp_create(NETADDR bindaddr)
 			sock.ipv6sock = socket;
 
 			/* set broadcast */
-			setsockopt(socket, SOL_SOCKET, SO_BROADCAST, (const char*)&broadcast, sizeof(broadcast));
+			if(setsockopt(socket, SOL_SOCKET, SO_BROADCAST, (const char*)&broadcast, sizeof(broadcast)) != 0)
+					dbg_msg("socket", "Setting BROADCAST on ipv6 failed: %d", errno);
 
 			{
 				/* set DSCP/TOS */
 				int iptos = 0x10 /* IPTOS_LOWDELAY */;
 				//int iptos = 46; /* High Priority */
-				setsockopt(socket, IPPROTO_IP, IP_TOS, (char*)&iptos, sizeof(iptos));
+				if(setsockopt(socket, IPPROTO_IP, IP_TOS, (char*)&iptos, sizeof(iptos)) != 0)
+					dbg_msg("socket", "Setting TOS on ipv6 failed: %d", errno);
 			}
 		}
 	}
@@ -1692,7 +1746,8 @@ int net_set_non_blocking(NETSOCKET sock)
 #if defined(CONF_FAMILY_WINDOWS)
 		ioctlsocket(sock.ipv4sock, FIONBIO, (unsigned long *)&mode);
 #else
-		ioctl(sock.ipv4sock, FIONBIO, (unsigned long *)&mode);
+		if(ioctl(sock.ipv4sock, FIONBIO, (unsigned long *)&mode) == -1)
+			dbg_msg("socket", "setting ipv4 non-blocking failed: %d", errno);
 #endif
 	}
 
@@ -1701,7 +1756,8 @@ int net_set_non_blocking(NETSOCKET sock)
 #if defined(CONF_FAMILY_WINDOWS)
 		ioctlsocket(sock.ipv6sock, FIONBIO, (unsigned long *)&mode);
 #else
-		ioctl(sock.ipv6sock, FIONBIO, (unsigned long *)&mode);
+		if(ioctl(sock.ipv6sock, FIONBIO, (unsigned long *)&mode) == -1)
+			dbg_msg("socket", "setting ipv6 non-blocking failed: %d", errno);
 #endif
 	}
 
@@ -1716,7 +1772,8 @@ int net_set_blocking(NETSOCKET sock)
 #if defined(CONF_FAMILY_WINDOWS)
 		ioctlsocket(sock.ipv4sock, FIONBIO, (unsigned long *)&mode);
 #else
-		ioctl(sock.ipv4sock, FIONBIO, (unsigned long *)&mode);
+		if(ioctl(sock.ipv4sock, FIONBIO, (unsigned long *)&mode) == -1)
+			dbg_msg("socket", "setting ipv4 blocking failed: %d", errno);
 #endif
 	}
 
@@ -1725,7 +1782,8 @@ int net_set_blocking(NETSOCKET sock)
 #if defined(CONF_FAMILY_WINDOWS)
 		ioctlsocket(sock.ipv6sock, FIONBIO, (unsigned long *)&mode);
 #else
-		ioctl(sock.ipv6sock, FIONBIO, (unsigned long *)&mode);
+		if(ioctl(sock.ipv6sock, FIONBIO, (unsigned long *)&mode) == -1)
+			dbg_msg("socket", "setting ipv6 blocking failed: %d", errno);
 #endif
 	}
 
@@ -2260,6 +2318,12 @@ void str_copy(char *dst, const char *src, int dst_size)
 	dst[dst_size-1] = 0; /* assure null termination */
 }
 
+void str_truncate(char *dst, int dst_size, const char *src, int truncation_len)
+{
+	int size = truncation_len >= dst_size ? dst_size : truncation_len + 1;
+	str_copy(dst, src, size);
+}
+
 int str_length(const char *str)
 {
 	return (int)strlen(str);
@@ -2273,14 +2337,26 @@ int str_format(char *buffer, int buffer_size, const char *format, ...)
 	va_start(ap, format);
 	ret = _vsnprintf(buffer, buffer_size, format, ap);
 	va_end(ap);
+
+	buffer[buffer_size-1] = 0; /* assure null termination */
+
+	/* _vsnprintf is documented to return negative values on truncation, but
+	 * in practice we didn't see that. let's handle it anyway just in case. */
+	if(ret < 0)
+		ret = buffer_size - 1;
 #else
 	va_list ap;
 	va_start(ap, format);
 	ret = vsnprintf(buffer, buffer_size, format, ap);
 	va_end(ap);
+
+	/* null termination is assured by definition of vsnprintf */
 #endif
 
-	buffer[buffer_size-1] = 0; /* assure null termination */
+	/* a return value of buffer_size or more indicates truncated output */
+	if(ret >= buffer_size)
+		ret = buffer_size - 1;
+
 	return ret;
 }
 
@@ -2581,6 +2657,11 @@ const char *str_find(const char *haystack, const char *needle)
 	return 0;
 }
 
+const char *str_rchr(const char *haystack, char needle)
+{
+	return strrchr(haystack, needle);
+}
+
 void str_hex(char *dst, int dst_size, const void *data, int data_size)
 {
 	static const char hex[] = "0123456789ABCDEF";
@@ -2717,8 +2798,20 @@ char str_uppercase(char c)
 	return c;
 }
 
+int str_isallnum(const char *str)
+{
+	while(*str)
+	{
+		if(!(*str >= '0' && *str <= '9'))
+			return 0;
+		str++;
+	}
+	return 1;
+}
+
 int str_toint(const char *str) { return atoi(str); }
 int str_toint_base(const char *str, int base) { return strtol(str, NULL, base); }
+unsigned long str_toulong_base(const char *str, int base) { return strtoul(str, NULL, base); }
 float str_tofloat(const char *str) { return atof(str); }
 
 int str_utf8_comp_nocase(const char *a, const char *b)
@@ -3041,9 +3134,13 @@ unsigned str_quickhash(const char *str)
 	return hash;
 }
 
-static const char *str_token_next(const char *str, const char *delim, int *length)
+static const char *str_token_get(const char *str, const char *delim, int *length)
 {
-	str += strspn(str, delim);
+	size_t len = strspn(str, delim);
+	if(len > 1)
+		str++;
+	else
+		str += len;
 	if(!*str)
 		return NULL;
 
@@ -3056,7 +3153,7 @@ int str_in_list(const char *list, const char *delim, const char *needle)
 	const char *tok = list;
 	int len = 0, notfound = 1, needlelen = str_length(needle);
 
-	while(notfound && (tok = str_token_next(tok, delim, &len)))
+	while(notfound && (tok = str_token_get(tok, delim, &len)))
 	{
 		notfound = needlelen != len || str_comp_num(tok, needle, len);
 		tok = tok + len;
@@ -3065,6 +3162,20 @@ int str_in_list(const char *list, const char *delim, const char *needle)
 	return !notfound;
 }
 
+const char *str_next_token(const char *str, const char *delim, char *buffer, int buffer_size)
+{
+	int len = 0;
+	const char *tok = str_token_get(str, delim, &len);
+	if(len < 0)
+		return NULL;
+
+	len = buffer_size > len ? len : buffer_size - 1;
+	mem_copy(buffer, tok, len);
+	buffer[len] = '\0';
+
+	return tok + len;
+}
+
 int pid()
 {
 #if defined(CONF_FAMILY_WINDOWS)
