@@ -8,12 +8,6 @@
 class CStorage : public IStorage
 {
 public:
-	enum
-	{
-		MAX_PATHS = 16,
-		MAX_PATH_LENGTH = 512
-	};
-
 	char m_aaStoragePaths[MAX_PATHS][MAX_PATH_LENGTH];
 	int m_NumPaths;
 	char m_aDatadir[MAX_PATH_LENGTH];
@@ -66,6 +60,7 @@ public:
 			fs_makedir(GetPath(TYPE_SAVE, "demos", aPath, sizeof(aPath)));
 			fs_makedir(GetPath(TYPE_SAVE, "demos/auto", aPath, sizeof(aPath)));
 			fs_makedir(GetPath(TYPE_SAVE, "demos/auto/race", aPath, sizeof(aPath)));
+			fs_makedir(GetPath(TYPE_SAVE, "demos/replays", aPath, sizeof(aPath)));
 			fs_makedir(GetPath(TYPE_SAVE, "editor", aPath, sizeof(aPath)));
 			fs_makedir(GetPath(TYPE_SAVE, "ghosts", aPath, sizeof(aPath)));
 			fs_makedir(GetPath(TYPE_SAVE, "teehistorian", aPath, sizeof(aPath)));
@@ -525,7 +520,7 @@ void IStorage::StripPathAndExtension(const char *pFilename, char *pBuffer, int B
 		}
 	}
 
-	int Length = min(BufferSize, (int)(pEnd - pExtractedName + 1));
+	int Length = minimum(BufferSize, (int)(pEnd - pExtractedName + 1));
 	str_copy(pBuffer, pExtractedName, Length);
 }
 
