@@ -105,7 +105,7 @@ void CHud::RenderGameTimer()
 
 	if(!(m_pClient->m_Snap.m_pGameInfoObj->m_GameStateFlags&GAMESTATEFLAG_SUDDENDEATH))
 	{
-		char Buf[32];
+		char aBuf[32];
 		int Time = 0;
 		if(m_pClient->m_Snap.m_pGameInfoObj->m_TimeLimit && (m_pClient->m_Snap.m_pGameInfoObj->m_WarmupTimer <= 0))
 		{
@@ -122,19 +122,14 @@ void CHud::RenderGameTimer()
 		else
 			Time = (Client()->GameTick()-m_pClient->m_Snap.m_pGameInfoObj->m_RoundStartTick)/Client()->GameTickSpeed();
 
-		CServerInfo Info;
-		Client()->GetServerInfo(&Info);
-
 		if(Time <= 0 && g_Config.m_ClShowDecisecs)
-			str_format(Buf, sizeof(Buf), "00:00.0");
+			str_format(aBuf, sizeof(aBuf), "00:00.0");
 		else if(Time <= 0)
-			str_format(Buf, sizeof(Buf), "00:00");
-		else if(IsRace(&Info) && !IsDDRace(&Info) && m_ServerRecord >= 0)
-			str_format(Buf, sizeof(Buf), "%02d:%02d", (int)(m_ServerRecord*100)/60, ((int)(m_ServerRecord*100)%60));
+			str_format(aBuf, sizeof(aBuf), "00:00");
 		else if(g_Config.m_ClShowDecisecs)
-			str_format(Buf, sizeof(Buf), "%02d:%02d.%d", Time/60, Time%60, m_DDRaceTick/10);
+			str_format(aBuf, sizeof(aBuf), "%02d:%02d.%d", Time/60, Time%60, m_DDRaceTick/10);
 		else
-			str_format(Buf, sizeof(Buf), "%02d:%02d", Time/60, Time%60);
+			str_format(aBuf, sizeof(aBuf), "%02d:%02d", Time/60, Time%60);
 		float FontSize = 10.0f;
 		float w;
 		if(g_Config.m_ClShowDecisecs)
@@ -147,7 +142,7 @@ void CHud::RenderGameTimer()
 			float Alpha = Time <= 10 && (2*time_get()/time_freq()) % 2 ? 0.5f : 1.0f;
 			TextRender()->TextColor(1.0f, 0.25f, 0.25f, Alpha);
 		}
-		TextRender()->Text(0, Half-w/2, 2, FontSize, Buf, -1);
+		TextRender()->Text(0, Half-w/2, 2, FontSize, aBuf, -1);
 		TextRender()->TextColor(1.0f, 1.0f, 1.0f, 1.0f);
 	}
 }
@@ -338,9 +333,7 @@ void CHud::RenderScoreHud()
 			{
 				if(apPlayerInfo[t])
 				{
-					CServerInfo Info;
-					Client()->GetServerInfo(&Info);
-					if(m_pClient->TimeScore() && g_Config.m_ClDDRaceScoreBoard)
+					if(m_pClient->m_GameInfo.m_TimeScore && g_Config.m_ClDDRaceScoreBoard)
 					{
 						if(apPlayerInfo[t]->m_Score != -9999)
 							str_format(aScore[t], sizeof(aScore[t]), "%02d:%02d", abs(apPlayerInfo[t]->m_Score)/60, abs(apPlayerInfo[t]->m_Score)%60);
@@ -768,31 +761,6 @@ void CHud::RenderLocalTime(float x)
 	TextRender()->Text(0, x-25.0f, (12.5f - 5.f) / 2.f, 5.0f, aTimeStr, -1);
 }
 
-void CHud::RenderPlayTime(float x)
-{
-	if(!g_Config.m_ClShowPlayTimeAlways && !m_pClient->m_pScoreboard->Active())
-		return;
-
-	// get the time
-	char aPlayTimeStr[6];
-	time_t CurrTime;
-	time(&CurrTime);
-	int Time = m_pClient->GetPlayTime(CurrTime) / 60;
-	str_format(aPlayTimeStr, sizeof(aPlayTimeStr), "%02d:%02d", Time/60, Time%60);
-
-	//draw the box
-	Graphics()->BlendNormal();
-	Graphics()->TextureSet(-1);
-	Graphics()->QuadsBegin();
-	Graphics()->SetColor(0.0f, 0.0f, 0.0f, 0.4f);
-	RenderTools()->DrawRoundRectExt(x-95.0f, 0.0f, 30.0f+TextRender()->TextWidth(0, 12, aPlayTimeStr, -1)/2, 12.5f, 3.75f, CUI::CORNER_B);
-	Graphics()->QuadsEnd();
-
-	//draw the text
-	TextRender()->Text(0, x-70.0f, (12.5f - 5.f) / 2.f, 5.0f, aPlayTimeStr, -1);
-	TextRender()->Text(0, x-90.0f, (12.5f - 5.f) / 2.f, 5.0f, "PLAYED", -1);
-}
-
 void CHud::OnRender()
 {
 	if(!m_pClient->m_Snap.m_pGameInfoObj)
@@ -825,7 +793,6 @@ void CHud::OnRender()
 		RenderWarmupTimer();
 		RenderTextInfo();
 		RenderLocalTime((m_Width/7)*3);
-		RenderPlayTime((m_Width/7)*3);
 		if(Client()->State() != IClient::STATE_DEMOPLAYBACK)
 			RenderConnectionWarning();
 		RenderTeambalanceWarning();
@@ -835,6 +802,17 @@ void CHud::OnRender()
 
 	}
 	RenderCursor();
+
+
+	static int LastChangeTick = 0;
+	if (LastChangeTick != Client()->PredGameTick())
+	{
+		m_DDRaceTick += 100 / Client()->GameTickSpeed();
+		LastChangeTick = Client()->PredGameTick();
+	}
+
+	if (m_DDRaceTick >= 100)
+		m_DDRaceTick = 0;
 }
 
 void CHud::OnMessage(int MsgType, void *pRawMsg)
@@ -869,13 +847,10 @@ void CHud::OnMessage(int MsgType, void *pRawMsg)
 	}
 	else if(MsgType == NETMSGTYPE_SV_RECORD)
 	{
-		CServerInfo Info;
-		Client()->GetServerInfo(&Info);
-
 		CNetMsg_Sv_Record *pMsg = (CNetMsg_Sv_Record *)pRawMsg;
 
 		// NETMSGTYPE_SV_RACETIME on old race servers
-		if(!IsDDRace(&Info) && IsRace(&Info))
+		if(GameClient()->m_GameInfo.m_DDRaceRecordMessage)
 		{
 			m_DDRaceTimeReceived = true;
 
@@ -890,7 +865,7 @@ void CHud::OnMessage(int MsgType, void *pRawMsg)
 				m_CheckpointTick = Client()->GameTick();
 			}
 		}
-		else
+		else if(GameClient()->m_GameInfo.m_RaceRecordMessage)
 		{
 			m_ServerRecord = (float)pMsg->m_ServerTimeBest/100;
 			m_PlayerRecord = (float)pMsg->m_PlayerTimeBest/100;
@@ -944,18 +919,6 @@ void CHud::RenderDDRaceEffects()
 			str_format(aBuf, sizeof(aBuf), "%02d:%02d.%d", m_DDRaceTime/60, m_DDRaceTime%60, m_DDRaceTick/10);
 			TextRender()->Text(0, 150*Graphics()->ScreenAspect()-TextRender()->TextWidth(0, 12,"00:00.0",-1)/2, 20, 12, aBuf, -1); // use fixed value for text width so its not shaky
 		}*/
-
-
-
-	static int LastChangeTick = 0;
-	if(LastChangeTick != Client()->PredGameTick())
-	{
-		m_DDRaceTick += 100/Client()->GameTickSpeed();
-		LastChangeTick = Client()->PredGameTick();
-	}
-
-	if(m_DDRaceTick >= 100)
-		m_DDRaceTick = 0;
 }
 
 void CHud::RenderRecord()
