@@ -11,7 +11,7 @@ class CMapImages : public CComponent
 	int m_aTextures[64];
 	int m_Count;
 
-	char m_aEntitiesGameType[16];
+	const char *m_pEntitiesGameType;
 public:
 	CMapImages();
 	CMapImages(int ImageSize);
@@ -43,6 +43,7 @@ private:
 	
 	void InitOverlayTextures();
 	int UploadEntityLayerText(int TextureSize, int YOffset);
+	void UpdateEntityLayerText(int TextureID, int TextureSize, int YOffset, int NumbersPower, int MaxNumber = -1);
 };
 
 #endif
