@@ -14,6 +14,27 @@
 
 #include <engine/shared/config.h>
 
+vec2 ClampVel(int MoveRestriction, vec2 Vel)
+{
+	if(Vel.x > 0 && (MoveRestriction&CANTMOVE_RIGHT))
+	{
+		Vel.x = 0;
+	}
+	if(Vel.x < 0 && (MoveRestriction&CANTMOVE_LEFT))
+	{
+		Vel.x = 0;
+	}
+	if(Vel.y > 0 && (MoveRestriction&CANTMOVE_DOWN))
+	{
+		Vel.y = 0;
+	}
+	if(Vel.y < 0 && (MoveRestriction&CANTMOVE_UP))
+	{
+		Vel.y = 0;
+	}
+	return Vel;
+}
+
 CCollision::CCollision()
 {
 	m_pTiles = 0;
@@ -131,6 +152,133 @@ void CCollision::Init(class CLayers *pLayers)
 	}
 }
 
+enum
+{
+	MR_DIR_HERE=0,
+	MR_DIR_RIGHT,
+	MR_DIR_DOWN,
+	MR_DIR_LEFT,
+	MR_DIR_UP,
+	NUM_MR_DIRS
+};
+
+static int GetMoveRestrictionsRaw(int Direction, int Tile, int Flags)
+{
+	Flags = Flags&(TILEFLAG_VFLIP|TILEFLAG_HFLIP|TILEFLAG_ROTATE);
+	switch(Tile)
+	{
+	case TILE_STOP:
+		switch(Flags)
+		{
+		case ROTATION_0: return CANTMOVE_DOWN;
+		case ROTATION_90: return CANTMOVE_LEFT;
+		case ROTATION_180: return CANTMOVE_UP;
+		case ROTATION_270: return CANTMOVE_RIGHT;
+
+		case TILEFLAG_HFLIP^ROTATION_0: return CANTMOVE_UP;
+		case TILEFLAG_HFLIP^ROTATION_90: return CANTMOVE_RIGHT;
+		case TILEFLAG_HFLIP^ROTATION_180: return CANTMOVE_DOWN;
+		case TILEFLAG_HFLIP^ROTATION_270: return CANTMOVE_LEFT;
+		}
+		break;
+	case TILE_STOPS:
+		switch(Flags)
+		{
+		case ROTATION_0:
+		case ROTATION_180:
+		case TILEFLAG_HFLIP^ROTATION_0:
+		case TILEFLAG_HFLIP^ROTATION_180:
+			return CANTMOVE_DOWN|CANTMOVE_UP;
+		case ROTATION_90:
+		case ROTATION_270:
+		case TILEFLAG_HFLIP^ROTATION_90:
+		case TILEFLAG_HFLIP^ROTATION_270:
+			return CANTMOVE_LEFT|CANTMOVE_RIGHT;
+		}
+		break;
+	case TILE_STOPA:
+		return CANTMOVE_LEFT|CANTMOVE_RIGHT|CANTMOVE_UP|CANTMOVE_DOWN;
+	}
+	return 0;
+}
+
+static int GetMoveRestrictionsMask(int Direction)
+{
+	switch(Direction)
+	{
+	case MR_DIR_HERE: return 0;
+	case MR_DIR_RIGHT: return CANTMOVE_RIGHT;
+	case MR_DIR_DOWN: return CANTMOVE_DOWN;
+	case MR_DIR_LEFT: return CANTMOVE_LEFT;
+	case MR_DIR_UP: return CANTMOVE_UP;
+	default: dbg_assert(false, "invalid dir");
+	}
+	return 0;
+}
+
+static int GetMoveRestrictions(int Direction, int Tile, int Flags)
+{
+	int Result = GetMoveRestrictionsRaw(Direction, Tile, Flags);
+	// Generally, stoppers only have an effect if they block us from moving
+	// *onto* them. The one exception is one-way blockers, they can also
+	// block us from moving if we're on top of them.
+	if(Direction == MR_DIR_HERE && Tile == TILE_STOP)
+	{
+		return Result;
+	}
+	return Result&GetMoveRestrictionsMask(Direction);
+}
+
+int CCollision::GetMoveRestrictions(CALLBACK_SWITCHACTIVE pfnSwitchActive, void *pUser, vec2 Pos, float Distance, int OverrideCenterTileIndex)
+{
+	static const vec2 DIRECTIONS[NUM_MR_DIRS] =
+	{
+		vec2(0, 0),
+		vec2(1, 0),
+		vec2(0, 1),
+		vec2(-1, 0),
+		vec2(0, -1)
+	};
+	dbg_assert(0.0f <= Distance && Distance <= 32.0f, "invalid distance");
+	int Restrictions = 0;
+	for(int d = 0; d < NUM_MR_DIRS; d++)
+	{
+		vec2 ModPos = Pos + DIRECTIONS[d] * Distance;
+		int ModMapIndex = GetPureMapIndex(ModPos);
+		if(d == MR_DIR_HERE && OverrideCenterTileIndex >= 0)
+		{
+			ModMapIndex = OverrideCenterTileIndex;
+		}
+		for(int Front = 0; Front < 2; Front++)
+		{
+			int Tile;
+			int Flags;
+			if(!Front)
+			{
+				Tile = GetTileIndex(ModMapIndex);
+				Flags = GetTileFlags(ModMapIndex);
+			}
+			else
+			{
+				Tile = GetFTileIndex(ModMapIndex);
+				Flags = GetFTileFlags(ModMapIndex);
+			}
+			Restrictions |= ::GetMoveRestrictions(d, Tile, Flags);
+		}
+		if(pfnSwitchActive)
+		{
+			int TeleNumber = GetDTileNumber(ModMapIndex);
+			if(pfnSwitchActive(TeleNumber, pUser))
+			{
+				int Tile = GetDTileIndex(ModMapIndex);
+				int Flags = GetDTileFlags(ModMapIndex);
+				Restrictions |= ::GetMoveRestrictions(d, Tile, Flags);
+			}
+		}
+	}
+	return Restrictions;
+}
+
 int CCollision::GetTile(int x, int y)
 {
 	if(!m_pTiles)
