@@ -232,6 +232,7 @@ public:
 	bool m_LeftWall;
 
 	// DDnet Character
+	void ReadDDNet(const CNetObj_DDNetCharacter *pObjDDNet);
 	bool m_Solo;
 	bool m_Jetpack;
 	bool m_NoCollision;
@@ -249,43 +250,16 @@ public:
 	int m_FreezeEnd;
 	bool m_DeepFrozen;
 
-	void LimitForce(vec2 *Force);
+	// Caps the given velocity according to the current set of stoppers
+	// that the character is affected by.
+	vec2 LimitVel(vec2 Vel);
 	void ApplyForce(vec2 Force);
 
 private:
 
 	CTeamsCore *m_pTeams;
-	int m_TileIndex;
-	int m_TileFlags;
-	int m_TileFIndex;
-	int m_TileFFlags;
-	int m_TileSIndex;
-	int m_TileSFlags;
-	int m_TileIndexL;
-	int m_TileFlagsL;
-	int m_TileFIndexL;
-	int m_TileFFlagsL;
-	int m_TileSIndexL;
-	int m_TileSFlagsL;
-	int m_TileIndexR;
-	int m_TileFlagsR;
-	int m_TileFIndexR;
-	int m_TileFFlagsR;
-	int m_TileSIndexR;
-	int m_TileSFlagsR;
-	int m_TileIndexT;
-	int m_TileFlagsT;
-	int m_TileFIndexT;
-	int m_TileFFlagsT;
-	int m_TileSIndexT;
-	int m_TileSFlagsT;
-	int m_TileIndexB;
-	int m_TileFlagsB;
-	int m_TileFIndexB;
-	int m_TileFFlagsB;
-	int m_TileSIndexB;
-	int m_TileSFlagsB;
-	bool IsRightTeam(int MapIndex);
+	int m_MoveRestrictions;
+	static bool IsSwitchActiveCb(int Number, void *pUser);
 };
 
 //input count
