@@ -35,7 +35,7 @@ void CGameContext::ConCredits(IConsole::IResult *pResult, void *pUserData)
 	pSelf->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "credits",
 		"Piepow, QingGo, RafaelFF, sctt, jao, daverck, fokkonaut,");
 	pSelf->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "credits",
-		"Bojidar & others.");
+		"Bojidar, FallenKN, ardadem, archimede67, sirius1242 & others.");
 	pSelf->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "credits",
 		"Based on DDRace by the DDRace developers,");
 	pSelf->Console()->Print(IConsole::OUTPUT_LEVEL_STANDARD, "credits",
@@ -285,7 +285,7 @@ void ToggleSpecPause(IConsole::IResult *pResult, void *pUserData, int PauseType)
 			pPlayer->SpectatePlayerName(pResult->GetString(0));
 		}
 	}
-	else if(-PauseState == PauseType)
+	else if(-PauseState != CPlayer::PAUSE_NONE && PauseType != CPlayer::PAUSE_NONE)
 	{
 		pPlayer->Pause(CPlayer::PAUSE_NONE, false);
 	}
@@ -511,7 +511,7 @@ void CGameContext::ConMap(IConsole::IResult *pResult, void *pUserData)
 			return;
 #endif
 
-	pSelf->Score()->MapVote(pResult->m_ClientID, pResult->GetString(0));
+	pSelf->Score()->MapVote(&pSelf->m_pMapVoteResult, pResult->m_ClientID, pResult->GetString(0));
 
 #if defined(CONF_SQL)
 	if(g_Config.m_SvUseSQL)
