@@ -57,6 +57,7 @@ class IConsole;
 class IEngine;
 class IStorage;
 class CRandomMapResult;
+class CMapVoteResult;
 
 class CGameContext : public IGameServer
 {
@@ -77,6 +78,7 @@ class CGameContext : public IGameServer
 	CMapBugs m_MapBugs;
 
 	std::shared_ptr<CRandomMapResult> m_pRandomMapResult;
+	std::shared_ptr<CMapVoteResult> m_pMapVoteResult;
 
 	static void CommandCallback(int ClientID, int FlagMask, const char *pCmd, IConsole::IResult *pResult, void *pUser);
 	static void TeeHistorianWrite(const void *pData, int DataSize, void *pUser);
@@ -372,15 +374,10 @@ private:
 		NETADDR m_Addr;
 		int m_Expire;
 	};
-	struct CVoteMute
-	{
-		NETADDR m_Addr;
-		int m_Expire;
-	};
 
 	CMute m_aMutes[MAX_MUTES];
 	int m_NumMutes;
-	CVoteMute m_aVoteMutes[MAX_VOTE_MUTES];
+	CMute m_aVoteMutes[MAX_VOTE_MUTES];
 	int m_NumVoteMutes;
 	bool TryMute(const NETADDR *pAddr, int Secs);
 	void Mute(const NETADDR *pAddr, int Secs, const char *pDisplayName);
