@@ -41,16 +41,16 @@ CFileScore::~CFileScore()
 	lock_unlock(gs_ScoreLock);
 }
 
-std::string SaveFile()
+std::string CFileScore::SaveFile()
 {
 	std::ostringstream oss;
 	char aBuf[256];
-	str_copy(aBuf, g_Config.m_SvMap, sizeof(aBuf));
+	str_copy(aBuf, Server()->GetMapName(), sizeof(aBuf));
 	for(int i = 0; i < 256; i++) if(aBuf[i] == '/') aBuf[i] = '-';
 	if (g_Config.m_SvScoreFolder[0])
 		oss << g_Config.m_SvScoreFolder << "/" << aBuf << "_record.dtb";
 	else
-		oss << g_Config.m_SvMap << "_record.dtb";
+		oss << Server()->GetMapName() << "_record.dtb";
 	return oss.str();
 }
 
@@ -59,7 +59,7 @@ void CFileScore::MapInfo(int ClientID, const char* MapName)
 	// TODO: implement
 }
 
-void CFileScore::MapVote(int ClientID, const char* MapName)
+void CFileScore::MapVote(std::shared_ptr<CMapVoteResult> *ppResult, int ClientID, const char* MapName)
 {
 	// TODO: implement
 }
@@ -69,10 +69,10 @@ void CFileScore::SaveScoreThread(void *pUser)
 	CFileScore *pSelf = (CFileScore *) pUser;
 	lock_wait(gs_ScoreLock);
 	std::fstream f;
-	f.open(SaveFile().c_str(), std::ios::out);
+	f.open(pSelf->SaveFile().c_str(), std::ios::out);
 	if(f.fail())
 	{
-		dbg_msg("filescore", "opening '%s' for writing failed", SaveFile().c_str());
+		dbg_msg("filescore", "opening '%s' for writing failed", pSelf->SaveFile().c_str());
 	}
 	else
 	{
@@ -266,7 +266,7 @@ void CFileScore::ShowTop5(IConsole::IResult *pResult, int ClientID,
 void CFileScore::ShowRank(int ClientID, const char* pName, bool Search)
 {
 	CPlayerScore *pScore;
-	int Pos = -1;
+	int Pos = -2;
 	char aBuf[512];
 
 	if (!Search)
